@@ -172,7 +172,7 @@ QString ProjectFileData::project() const
     if (project) {
         return project->name();
     } else {
-        return i18n("none");
+        return i18nc("@item no project", "none");
     }
 }
 
@@ -197,7 +197,11 @@ void BaseFileDataProvider::setFilterText(const QString& text)
             path = Path(Path(doc->url()).parent(), path).pathOrUrl();
         }
     }
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    setFilter(path.split(QLatin1Char('/'), Qt::SkipEmptyParts));
+#else
     setFilter(path.split(QLatin1Char('/'), QString::SkipEmptyParts));
+#endif
 }
 
 uint BaseFileDataProvider::itemCount() const
